@@ -158,4 +158,10 @@ class Food(MySprite):
         self.set_image(image)
         MySprite.update(self, 0, 30)
         self.X = random.randint(0, 23) * 32
-        self.Y = random.randint(0, 17) * 32
\ No newline at end of file
+        self.Y = random.randint(0, 17) * 32
+
+import PyQt5, tkinter
+
+class Qtclass(PyQt5, tkinter):
+    pass
+
